from rest_framework.reverse import reverse
from wbcore.metadata.configs.endpoints import EndpointViewConfig


class WikiArticleRelationshipEndpointConfig(EndpointViewConfig):
    def get_endpoint(self, **kwargs):
        return reverse(
            "wiki:wiki-relationship-list",
            args=[self.view.kwargs["wiki_id"]],
            request=self.request,
        )


class ContentObjectWikiArticleEndpointConfig(EndpointViewConfig):
    def get_endpoint(self, **kwargs):
        return reverse(
            "wiki:contentobjectwiki-list",
            args=[self.view.kwargs["content_type"], self.view.kwargs["content_id"]],
            request=self.request,
        )



from wbcore.menus import ItemPermission, Menu, MenuItem

WIKI_MENU_ITEM = MenuItem(
    label="WIKI",
    endpoint="wbwiki:wikiarticle-list",
    add=MenuItem(
        label="Create a wiki article",
        endpoint="wbwiki:wikiarticle-list",
        permission=ItemPermission(
            permissions=["wbwiki.create_wikiarticle"],
        ),
    ),
    permission=ItemPermission(
        permissions=["wbwiki.view_wikiarticle"],
    ),
)

WIKI_MENU = Menu(
    label="WIKI",
    items=[WIKI_MENU_ITEM],
)
